@@ -388,6 +388,17 @@ def get_interface_connections(dispatcher, filter_type, filter_value_1, filter_va
                 f'Unknown filter type "{filter_type}"',
             )  # command did not run to completion and therefore should not be logged
 
+        # Check on empty choice list, send an error back
+        if not choices:
+            dispatcher.send_markdown(
+                message=f"Unable to filter by '{filter_type}', as it appears there is no corresponding data available",
+                ephemeral=True,
+            )
+            return (
+                CommandStatusChoices.STATUS_FAILED,
+                f'No choices found when filtering by "{filter_type}"',
+            )
+
         if filter_type != "device":
             dispatcher.prompt_from_menu(
                 f"nautobot get-interface-connections {filter_type}",
@@ -976,3 +987,15 @@ def get_circuit_providers(dispatcher, *args):
 
     dispatcher.send_large_table(header, rows)
     return CommandStatusChoices.STATUS_SUCCEEDED
+
+
+@subcommand_of("nautobot")
+def about(dispatcher, *args):
+    """Provide link for more information on Nautobot Apps."""
+    url = "https://www.networktocode.com/nautobot/apps/"
+    blocks = [
+        dispatcher.markdown_block(f"More Chat commands can be found at {dispatcher.hyperlink('Nautobot Apps', url)}"),
+    ]
+
+    dispatcher.send_blocks(blocks)
+    return CommandStatusChoices.STATUS_SUCCEEDED
